Class: Tbx::Sc

Inherits:
Lutaml::Model::Serializable
  • Object
show all
Defined in:
lib/tbx/sc.rb

Overview

XLIFF inline start-code marker ‘<sc>`.

Used for representing inline formatting codes from source formats. The ‘id` is required and is referenced by a corresponding `<ec>` element’s ‘startRef`.

Attributes per core RNG: ‘id` (required, type ID), `isolated` (optional, yes/no). Schema source: TBXcoreStructV03.rng `<define name=“sc”>`