Class: Tbx::RefObjectSec
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Tbx::RefObjectSec
- Defined in:
- lib/tbx/ref_object_sec.rb
Overview
Reference object section ‘<refObjectSec>` in back matter.
Contains reference objects that define picklists and value sets used by data category elements throughout the termbase.
Schema source: TBXcoreStructV03.rng ‘<define name=“refObjectSec”>`